Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(392)

Unified Diff: chrome/browser/chromeos/gdata/operation_runner.h

Issue 10879061: Rename GDataOperationInterface to AuthenticatedOperationInterface (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chromeos/gdata/auth_service.cc ('k') | chrome/browser/chromeos/gdata/operation_runner.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/gdata/operation_runner.h
diff --git a/chrome/browser/chromeos/gdata/operation_runner.h b/chrome/browser/chromeos/gdata/operation_runner.h
index dfb9eb71c2cdf6fa10fbbd1da53874cbbd909882..a6e8011f3a5fa551a9a5244db7bdbd85bbcdc041 100644
--- a/chrome/browser/chromeos/gdata/operation_runner.h
+++ b/chrome/browser/chromeos/gdata/operation_runner.h
@@ -17,11 +17,11 @@ class Profile;
namespace gdata {
-class GDataOperationInterface;
+class AuthenticatedOperationInterface;
class OperationRegistry;
// Helper class that runs GDataOperationInterface objects, handling retries and
// authentication.
class OperationRunner : public AuthService::Observer {
public:
explicit OperationRunner(Profile* profile);
@@ -43,22 +43,23 @@ class OperationRunner : public AuthService::Observer {
// function is run.
void Authenticate(const AuthStatusCallback& callback);
- // Starts an operation implementing the GDataOperationInterface interface, and
- // makes the operation retry upon authentication failures by calling back to
- // RetryOperation.
- void StartOperationWithRetry(GDataOperationInterface* operation);
+ // Starts an operation implementing the AuthenticatedOperationInterface
+ // interface, and makes the operation retry upon authentication failures by
+ // calling back to RetryOperation.
+ void StartOperationWithRetry(AuthenticatedOperationInterface* operation);
- // Starts an operation implementing the GDataOperationInterface interface.
- void StartOperation(GDataOperationInterface* operation);
+ // Starts an operation implementing the AuthenticatedOperationInterface
+ // interface.
+ void StartOperation(AuthenticatedOperationInterface* operation);
// Called when the authentication token is refreshed.
- void OnOperationAuthRefresh(GDataOperationInterface* operation,
+ void OnOperationAuthRefresh(AuthenticatedOperationInterface* operation,
GDataErrorCode error,
const std::string& auth_token);
// Clears any authentication token and retries the operation, which
// forces an authentication token refresh.
- void RetryOperation(GDataOperationInterface* operation);
+ void RetryOperation(AuthenticatedOperationInterface* operation);
private:
// AuthService::Observer override.
« no previous file with comments | « chrome/browser/chromeos/gdata/auth_service.cc ('k') | chrome/browser/chromeos/gdata/operation_runner.cc » ('j') | no next file with comments »
@@ -17,11 +17,11 @@ class Profile;
class OperationRegistry;
-// Helper class that runs GDataOperationInterface objects, handling retries and
-// authentication.
+// Helper class that runs AuthenticatedOperationInterface objects, handling
+// retries and authentication.
class OperationRunner : public AuthService::Observer {
public:

Powered by Google App Engine
This is Rietveld 408576698